@@ -1053,10 +1053,6 @@ class Horde_ActiveSync_Imap_Adapter
             $eas_message->displayto = $eas_message->to;
         }
 
-        // Ensure we don't send broken UTF8 data to the client. It makes clients
-        // angry. And we don't like angry clients.
-        $hdr_charset = $imap_message->getStructure()->getHeaderCharset();
-
         // Fill in other header data
         try {
             $eas_message->from = $imap_message->getFromAddress();
@@ -1074,7 +1070,12 @@ class Horde_ActiveSync_Imap_Adapter
             $this->_logger->err($e->getMessage());
         }
 
-        $eas_message->subject = Horde_ActiveSync_Utils::ensureUtf8($imap_message->getSubject(), $hdr_charset);
+        // Ensure we don't send broken UTF8 data to the client. It makes clients
+        // angry. And we don't like angry clients.
+        $eas_message->subject = Horde_ActiveSync_Utils::ensureUtf8(
+            $imap_message->getSubject(),
+            $imap_message->getStructure()->getHeaderCharset()
+        );
         $eas_message->threadtopic = $eas_message->subject;
         $eas_message->datereceived = $imap_message->getDate();
         $eas_message->read = $imap_message->getFlag(Horde_Imap_Client::FLAG_SEEN);
