@@ -27,7 +27,7 @@ class Horde_ActiveSync_AppointmentTest extends Horde_Test_Case
      */
     public function testEncoding()
     {
-        $this->markTestSkipped('Needs updated fixture.');
+        $this->markTestIncomplete('Needs updated fixture.');
         $l = new Horde_Test_Log();
         $logger = $l->getLogger();
 
@@ -94,7 +94,7 @@ class Horde_ActiveSync_AppointmentTest extends Horde_Test_Case
 
     public function testEncodingRecurrence()
     {
-        $this->markTestSkipped('Needs updated fixture.');
+        $this->markTestIncomplete('Needs updated fixture.');
         $l = new Horde_Test_Log();
         $logger = $l->getLogger();
 
@@ -175,7 +175,7 @@ class Horde_ActiveSync_AppointmentTest extends Horde_Test_Case
 
     public function testEncodingSimpleExceptions()
     {
-        $this->markTestSkipped('Needs updated fixture.');
+        $this->markTestIncomplete('Needs updated fixture.');
         $l = new Horde_Test_Log();
         $logger = $l->getLogger();
         //$logger = new Horde_Log_Logger(new Horde_Log_Handler_Stream(fopen('/tmp/test.log', 'a')));
